﻿--[[

Copyright (C) 2004 by neuron
aagaande AT gmail DOT com

This program is free software; you can redistribute it and--or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the
Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

]]

local nQuestLog = nQuestLog

local REVISION = tonumber(("$Revision: 56158 $"):match("%d+"))
if ( nQuestLog.revision < REVISION ) then
	nQuestLog.version = (nQuestLog.versionstring):format(REVISION)
	nQuestLog.revision = REVISION
	nQuestLog.date = ("$Date: 2007-11-28 01:03:46 -0500 (Wed, 28 Nov 2007) $"):match("%d%d%d%d%-%d%d%-%d%d")
end

local moduleName = "Coloring"
local Coloring = nQuestLog:NewModule(moduleName,"AceEvent-2.0","AceHook-2.1", "AceConsole-2.0")

--Load libraries
local Crayon = AceLibrary("Crayon-2.0")
local Tourist = AceLibrary("Tourist-2.0")

--Load localization
local L = AceLibrary("AceLocale-2.2"):new("Coloring")

function Coloring:OnModuleLoad()
	self.menuName = L["Coloring"]
	self.description = L["Description"]
	if ( not self.defaultsRegistered ) then
		self.core:RegisterDefaults(moduleName, "profile", { enabled = true,
			trackerBorderColor = { r = 255, g = 255, b = 255, a = 0 },
			trackerBackgroundColor = { r = 31, g = 32, b = 94, a = 0.6 },
			zoneHeader = { r = 119, g = 187, b = 255, threshold = false },
			zoneLevel = { r = 119, g = 187, b = 255, threshold = false},
			questHeader = { r = 255, g = 255, b = 255, threshold = true},
			questHighlight = { r = 91, g = 135, b = 229, a = 0.8 },
			questProgress = { r = 255, g = 255, b = 255, threshold = true },
			questFailed = { r = 255, g = 255, b = 255 },
			questGoto = { r = 255, g = 255, b = 255 },
			questDone = { r = 255, g = 255, b = 255 },
			objectiveHeader = { r = 255, g = 255, b = 255, threshold = false },
			objectiveProgress = { r = 255, g = 255, b = 255, threshold = true},
			objectiveText = { r = 237, g = 165, b = 95 },
			notificationColor = { r = 255, g = 255, b = 0 } })
		self.defaultsRegistered = true
	end
end

function Coloring:GetMenu(oldMenu)
	local menu = { order = oldMenu.order, type = "group",
		name = self.menuName, desc = self.description,
		cmdHidden = true,
		args = { toggleEnabled = oldMenu } }
	local colorList = {
		{ name = "trackerBorderColor" },
		{ name = "trackerBackgroundColor" },
		{ name = "zoneHeader", extra = "Color by level" },
		{ name = "zoneLevel",extra = "Color by level" },
		{ name = "questHeader", extra = "Color by level" },
		{ name = "questHighlight" },
		{ name = "questProgress", extra = "Color by progress" },
		{ name = "questFailed" },
		{ name = "questGoto" },
		{ name = "questDone" },
		{ name = "objectiveHeader", extra = "Color by progress" },
		{ name = "objectiveProgress", extra = "Color by progress" },
		{ name = "objectiveText" },
		{ name = "notificationColor" } }
	local function getColor(var)
		return self.db.profile[var].r / 255, self.db.profile[var].g / 255,
			self.db.profile[var].b / 255, self.db.profile[var].a
	end
	local function setColor(var, r, g, b, a)
		self.db.profile[var] = { r = r * 255, g = g * 255, b = b * 255, a = a}
		self.core:RefreshTracker()
	end
	local function getToggle(var)
		return self.db.profile[var].threshold
	end
	local function setToggle(var, v)
		self.db.profile[var].threshold = v
		self.core:RefreshTracker()
	end
	for i,color in ipairs(colorList) do
		local name = colorList[i].name
		local extra = colorList[i].extra
		local hasAlpha = false
		if self.db.profile[name].a then
			hasAlpha = true
		end
		local colorMenu = { order = 1200 + i, type = "color",			
			name = L[name],
			desc = L["Change color settings for"].." "..L[name],
			get = function()
				return getColor(name)
			end,
			set = function(r, g, b, a)
				setColor(name, r, g, b, a)
			end,
			hasAlpha = hasAlpha }
		if ( extra ) then
			menu.args[name] = { order = 1200 + i, type = "group",
				name = L[name],
				desc = L["Change color settings for"].." "..L[name],
				args = {
					name = colorMenu,
					extra = {
						type = "toggle",
						name = " - "..L[extra],
						desc = L["Change color settings for"].." "..L[extra],
						order = 1200 + i + 1,
						get = function()
							return getToggle(name)
						end,
						set = function(v)
							setToggle(name, v)
						end } } }
		else
			menu.args[name] = colorMenu
		end
	end
	return menu
end

function Coloring:Colorize(text,variable,range,zone,level)
	--Colorize text, using variable for settings
	--Range is for threshold colorizing, so is zone
	--If level and threshold then colorize by level

	--Range and zone is optional, will be used if threshold=true
	if ( range ) and ( self.db.profile[variable].threshold ) then
		--Color by range, for example got/needed
		local color = Crayon:GetThresholdHexColor(range)
		return Crayon:Colorize(color, text)
	elseif ( zone ) and ( self.db.profile[variable].threshold ) then
		--Color by zone
		local low, high = Tourist:GetLevel(zone)
		local color = Crayon:GetThresholdHexColor(low / high)
		return Crayon:Colorize(color, text)
	elseif ( level ) and ( self.db.profile[variable].threshold ) then
		local color = GetDifficultyColor(level)
		color = ("%02x%02x%02x"):format(color.r * 255, color.g * 255, color.b * 255)
		return Crayon:Colorize(color, text)
	end
	--Take predefined color
	local color = ("%02x%02x%02x"):format(self.db.profile[variable].r, self.db.profile[variable].g, self.db.profile[variable].b)
	return Crayon:Colorize(color, text)
end

function Coloring:GetColor(variable)
	return self.db.profile[variable]
end
